# Table of Contents

- [status-pages-and-status-emails](<./status-pages-and-status-emails.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Status Pages and Status Emails](<./Status-Pages-and-Status-Emails.md>)
  - [Overview](<./Status-Pages-and-Status-Emails/Overview.md>)
  - [Accessing the Availability Page in SAP for Me](<./Status-Pages-and-Status-Emails/Accessing-the-Availability-Page-in-SAP-for-Me.md>)
  - [Configuring Status Emails](<./Status-Pages-and-Status-Emails/Configuring-Status-Emails.md>)
  - [Additional Information](<./Status-Pages-and-Status-Emails/Additional-Information.md>)
